2.6.0 - 25th September 2019
~~~~~~~~~~~~~~~~~~~~~~~~~~~

- Catch missing ``older_available`` property
- Fix undefined parameters in ``about_topic`` and ``find``

2.5.0 - 7th November 2017
~~~~~~~~~~~~~~~~~~~~~~~~~

- Added support for HTTP proxies

2.3.0 - 24th Jan 2017
~~~~~~~~~~~~~~~~~~~~~

- Added paging support for all message related APIs
